@@ -1,5 +1,8 @@
 
 
+#' @importFrom dplyr n
+NULL
+
 getConcreteTableName <- function(handle) {
   # TODO: get a safe way to get the concrete name
   #  https://github.com/tidyverse/dplyr/issues/2824
@@ -299,7 +302,6 @@ tableDescription <- function(tableName,
 #' @export
 #'
 keysAreUnique <- function(tDesc) {
-  n <- dplyr::n # declare not  unbound
   isunique <- vapply(seq_len(replyr_nrow(tDesc)),
                      function(i) {
                        gi <- tDesc$handle[[i]]
@@ -750,7 +752,6 @@ inspectDescrAndJoinPlan <- function(tDesc, columnJoinPlan,
 buildJoinPlan <- function(tDesc,
                           ...,
                           check= TRUE) {
-  n <- dplyr::n # declare not an unbound ref
   count <- NULL # declare not an unbound ref
   ntab <- replyr_nrow(tDesc)
   if(length(unique(tDesc$tableName))!=ntab) {
